ViewStorage class abstract

Interface implemented by compiler backend to provide persistant storage of instances for AppView.

Implementers

Constructors

ViewStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocate(String name, {OutputType outputType = o.OBJECT_TYPE, required List<StmtModifier> modifiers, Expression? initializer}) → ViewStorageItem
buildReadExpr(ViewStorageItem item) → Expression
buildWriteExpr(ViewStorageItem item, Expression value) → Expression
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited